@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
 ## Copyright (C) 2008 Novell, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
@@ -16,7 +16,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import threading
 import config
@@ -596,7 +596,7 @@ class IPPAuthConnection(IPPConnection):
                                 host=host, port=port, encryption=encryption)
 
     def destroy (self):
-        del self.semantic
+        self.semantic = None
         IPPConnection.destroy (self)
 
     def _call_function (self, fn, *args, **kwds):
