@@ -1,8 +1,9 @@
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010 Red Hat, Inc.
-## Copyright (C) 2006 Florian Festi <ffesti@redhat.com>
-## Copyright (C) 2006, 2007, 2008, 2009, 2010 Tim Waugh <twaugh@redhat.com>
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Authors:
+##  Florian Festi <ffesti@redhat.com>
+##  Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups, pprint, os, tempfile, re, string
 import locale
@@ -37,7 +38,18 @@ class Printer:
         self.name = name
         self.connection = connection
         self.class_members = []
-        self.update (**kw)
+        have_kw = len (kw) > 0
+        fetch_attrs = True
+        if have_kw:
+            self.update (**kw)
+            if self.is_class:
+                fetch_attrs = True
+            else:
+                fetch_attrs = False
+
+        if fetch_attrs:
+            self.getAttributes ()
+
         self._ppd = None # load on demand
 
     def __del__ (self):
@@ -45,7 +57,7 @@ class Printer:
             os.unlink(self._ppd)
 
     def __repr__ (self):
-        return "<cupshelpers.Printer \"%s\" at 0x%x>" % (self.name, id (self))
+        return "<cupshelpers.Printer \"%s\">" % self.name
 
     def _expand_flags(self):
 
@@ -89,6 +101,10 @@ class Printer:
         if self.is_shared is None:
             self.is_shared = not self.not_shared
         del self.not_shared
+        self.class_members = kw.get('member-names', [])
+        if type (self.class_members) != list:
+            self.class_members = [self.class_members]
+        self.class_members.sort ()
         self.other_attributes = kw
 
     def getAttributes(self):
@@ -671,14 +687,13 @@ def setPPDPageSize(ppd, language):
     except:
         _debugprint ("Failed to set PageSize (%s not available?)" % size)
 
-def missingPackagesAndExecutables(ppd):
+def missingExecutables(ppd):
     """
     Check that all relevant executables for a PPD are installed.
 
     @param ppd: PPD
     @type ppd: cups.PPD object
-    @returns: string list pair, representing missing packages and
-    missing executables
+    @returns: string list, representing missing executables
     """
 
     # First, a local function.  How to check that something exists
@@ -719,9 +734,16 @@ def missingPackagesAndExecutables(ppd):
         _debugprint ("%s: NOT found in %s" % (name,path))
         return None
 
-    pkgs_to_install = []
     exes_to_install = []
 
+    def add_missing (exe):
+        # Strip out foomatic '%'-style place-holders.
+        p = exe.find ('%')
+        if p != -1:
+            exe = exe[:p]
+
+        exes_to_install.append (exe)
+
     # Find a 'FoomaticRIPCommandLine' attribute.
     exe = exepath = None
     attr = ppd.findAttr ('FoomaticRIPCommandLine')
@@ -745,7 +767,8 @@ def missingPackagesAndExecutables(ppd):
                 exe = args[0]
                 exepath = pathcheck (exe)
                 if not exepath:
-                    break
+                    add_missing (exe)
+                    continue
 
                 # Main executable found.  But if it's 'gs',
                 # perhaps there is an IJS server we also need
@@ -759,6 +782,9 @@ def missingPackagesAndExecutables(ppd):
                         if arg.startswith (search):
                             exe = arg[len (search):]
                             exepath = pathcheck (exe)
+                            if not exepath:
+                                add_missing (exe)
+
                             break
 
                         argi += 1
@@ -787,54 +813,22 @@ def missingPackagesAndExecutables(ppd):
                 exepath = pathcheck (exe,
                                      "/usr/lib/cups/filter:"
                                      "/usr/lib64/cups/filter")
+                if not exepath:
+                    add_missing ("/usr/lib/cups/filter/" + exe)
 
-    if exe and not exepath:
-        # We didn't find a necessary executable.  Complain.
+    return exes_to_install
 
-        # Strip out foomatic '%'-style place-holders.
-        p = exe.find ('%')
-        if p != -1:
-            exe = exe[:p]
+def missingPackagesAndExecutables(ppd):
+    """
+    Check that all relevant executables for a PPD are installed.
 
-        pkgs = {
-            # The foomatic filter
-            'foomatic-rip': 'foomatic',
-            # Foomatic command line executables
-            'gs': 'ghostscript',
-            'perl': 'perl',
-            'foo2oak-wrapper': None,
-            'pnm2ppa': 'pnm2ppa',
-            'c2050': 'c2050',
-            'c2070': 'c2070',
-            'cjet': 'cjet',
-            'lm1100': 'lx',
-            'esc-m': 'min12xxw',
-            'min12xxw': 'min12xxw',
-            'pbm2l2030': 'pbm2l2030',
-            'pbm2l7k': 'pbm2l7k',
-            'pbm2lex': 'pbm2l7k',
-            # IJS servers (used by foomatic)
-            'hpijs': 'hpijs',
-            'ijsgutenprint.5.0': 'gutenprint',
-            'ijsgutenprint.5.2': 'gutenprint',
-            # CUPS filters
-            'rastertogutenprint.5.0': 'gutenprint-cups',
-            'rastertogutenprint.5.2': 'gutenprint-cups',
-            'commandtoepson': 'gutenprint-cups',
-            'commandtocanon': 'gutenprint-cups',
-            }
-        try:
-            pkg = pkgs[exe]
-        except:
-            pkg = None
-
-        if pkg:
-            _debugprint ("%s included in package %s" % (exe, pkg))
-            pkgs_to_install.append (pkg)
-        else:
-            exes_to_install.append (exe)
-
-    return (pkgs_to_install, exes_to_install)
+    @param ppd: PPD
+    @type ppd: cups.PPD object
+    @returns: string list pair, representing missing packages and
+    missing executables
+    """
+    executables = missingExecutables(ppd)
+    return ([], executables)
 
 def _main():
     c = cups.Connection()
