@@ -17,7 +17,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import dbus
 import gobject
@@ -130,6 +130,8 @@ class PPDsLoader(gobject.GObject):
         return self._exc
 
     def _dialog_response (self, dialog, response):
+        dialog.destroy ()
+        self._dialog = None
         self.emit ('finished')
 
     def _query_cups (self):
@@ -149,7 +151,7 @@ class PPDsLoader(gobject.GObject):
             conn.getPPDs2 (reply_handler=self._cups_reply,
                            error_handler=self._cups_error)
         except AttributeError:
-            # getPPDs requires pycups >= 1.9.52
+            # getPPDs2 requires pycups >= 1.9.52
             conn.getPPDs (reply_handler=self._cups_reply,
                           error_handler=self._cups_error)
 
@@ -187,12 +189,20 @@ class PPDsLoader(gobject.GObject):
 
         conn.destroy ()
         self._conn = None
+        if self._dialog != None:
+            self._dialog.destroy ()
+            self._dialog = None
+
         self.emit ('finished')
 
     def _cups_error (self, conn, exc):
         conn.destroy ()
         self._conn = None
         self._ppds = None
+        if self._dialog != None:
+            self._dialog.destroy ()
+            self._dialog = None
+
         self.emit ('finished')
 
     def _query_packagekit (self):
@@ -259,8 +269,14 @@ class PPDsLoader(gobject.GObject):
         if self._need_requery_cups:
             self._query_cups ()
         else:
-            self._conn.destroy ()
-            self._conn = None
+            if self._conn != None:
+                self._conn.destroy ()
+                self._conn = None
+
+            if self._dialog != None:
+                self._dialog.destroy ()
+                self._dialog = None
+
             self.emit ('finished')
 
 gobject.type_register(PPDsLoader)
