@@ -1,6 +1,6 @@
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
 ## Copyright (C) 2006 Florian Festi <ffesti@redhat.com>
 ## Copyright (C) 2007, 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
@@ -16,7 +16,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cupshelpers
 from debug import *
@@ -29,6 +29,7 @@ import threading
 import errno
 import cups
 import gobject
+import smburi
 
 try:
     import pysmb
@@ -122,6 +123,7 @@ class LpdServer:
     def __init__(self, hostname):
         self.hostname = hostname
         self.max_lpt_com = 8
+        self.stop = False
 
     def probe_queue(self,name, result):
         s = open_socket(self.hostname, 515)
@@ -170,12 +172,19 @@ class LpdServer:
 
         return candidate
 
+    def destroy(self):
+        debugprint ("LpdServer exiting: destroy called")
+        self.stop = True
+
     def probe(self):
         result = []
         for name in self.get_possible_queue_names ():
             while gtk.events_pending ():
                 gtk.main_iteration ()
 
+            if self.stop:
+                break
+
             found = self.probe_queue(name, result)
             if not found and name.startswith ("pr"):
                 break
@@ -379,7 +388,7 @@ class PrinterFinder:
         entries = []
         uri = "smb://%s/" % self.hostname
         debugprint ("smb: trying")
-        try:
+        if False: #try:
             while smbc_auth.perform_authentication () > 0:
                 if self.quit:
                     debugprint ("smb: no good")
@@ -389,11 +398,18 @@ class PrinterFinder:
                     entries = ctx.opendir (uri).getdents ()
                 except Exception, e:
                     smbc_auth.failed (e)
-        except RuntimeError, (e, s):
-            if e not in [errno.ENOENT, errno.EACCES, errno.EPERM]:
-                debugprint ("Runtime error: %s" % repr ((e, s)))
-        except:
-            nonfatalException ()
+        #except RuntimeError, (e, s):
+        #    if e not in [errno.ENOENT, errno.EACCES, errno.EPERM]:
+        #        debugprint ("Runtime error: %s" % repr ((e, s)))
+        #except:
+        #    nonfatalException ()
+        #class Foo:
+        #    pass
+
+        #entry = Foo()
+        #entry.name = "Samsung SCX4200"
+        #entry.smbc_type = pysmb.smbc.PRINTER_SHARE
+        #entries = [ entry ]
 
         if self.quit:
             debugprint ("smb: no good")
@@ -401,7 +417,8 @@ class PrinterFinder:
 
         for entry in entries:
             if entry.smbc_type == pysmb.smbc.PRINTER_SHARE:
-                uri = "smb://%s/%s" % (self.hostname, entry.name)
+                uri = "smb://%s/%s" % (smburi.urlquote (self.hostname),
+                                       smburi.urlquote (entry.name))
                 info = "SMB (%s)" % self.hostname
                 self._new_device(uri, info)
 
