@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2008, 2009, 2010 Red Hat, Inc.
+## Copyright (C) 2008, 2009, 2010, 2011 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -18,11 +18,12 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import config
 from gettext import gettext as _
 import cups
+import dbus
 import gobject
 import gtk
 import os
@@ -257,7 +258,7 @@ class ServerSettings(GtkGUI):
 
     def on_add_clicked (self, button):
         model = self.browse_treeview.get_model ()
-        iter = model.insert (0, row=[_("Enter IP address")])
+        iter = model.insert (0, row=[_("Enter hostname")])
         button.set_sensitive (False)
         col = self.browse_treeview.get_columns ()[0]
         cell = col.get_cell_renderers ()[0]
